@@ -3,32 +3,7 @@
 # function from this script and follow the docs for creating a logger object.
 # Alternatively, you can simply import the 'LOGGER' object for a development env
 import logging
-
-
-class LogColourFormatter(logging.Formatter):
-
-    grey = "\x1b[38;20m"
-    magneta = "\x1b[35m"
-    yellow = "\x1b[33;20m"
-    red = "\x1b[31;20m"
-    bold_red = "\x1b[31;1m"
-    reset = "\x1b[0m"
-    format = (
-        "%(asctime)s - %(name)s - %(levelname)s - %(message)s (%(filename)s:%(lineno)d)"
-    )
-
-    FORMATS = {
-        logging.DEBUG: magneta + format + reset,
-        logging.INFO: grey + format + reset,
-        logging.WARNING: yellow + format + reset,
-        logging.ERROR: red + format + reset,
-        logging.CRITICAL: bold_red + format + reset,
-    }
-
-    def format(self, record):
-        log_fmt = self.FORMATS.get(record.levelno)
-        formatter = logging.Formatter(log_fmt)
-        return formatter.format(record)
+from logster.classes import LogColourFormatter
 
 
 def setup_logger(name=None, level="INFO"):
